@@ -207,7 +207,6 @@
     (lambda (obj)
       (pair? (cyclic-sequences obj)))))
 
-
 (define copy-tree
   (let ((+documentation+ "(copy-tree lst) returns a full copy of lst"))
     (lambda (lis)
@@ -1452,10 +1451,9 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
        (L ()))
       ((null? p) 
        (reverse L))
-    (unless (memq (caar p) '(memory-usage stack gc-protected-objects))
-      (set! L (cons (cdar p) 
-		    (cons (symbol->keyword (caar p))
-			  L))))))
+    (set! L (cons (cdar p) 
+		  (cons (symbol->keyword (caar p))
+			L)))))
 
 
 ;;; --------------------------------------------------------------------------------
